@@ -8,7 +8,7 @@ from django.conf import settings
 from django.contrib.auth.models import User
 from sanza.Crm import models
 from sanza.Crm.widgets import CityAutoComplete, EntityAutoComplete, OpportunityAutoComplete, ContactAutoComplete
-from sanza.Crm.settings import get_default_country
+from sanza.Crm.settings import get_default_country, NO_ENTITY_TYPE
 from datetime import datetime, date
 from form_utils.forms import BetterModelForm, BetterForm
 from djaloha.widgets import AlohaInput
@@ -200,6 +200,9 @@ class EntityForm(ModelFormWithCity):
     def __init__(self, *args, **kwargs):
         super(EntityForm, self).__init__(*args, **kwargs)
         
+        if NO_ENTITY_TYPE:
+            self.fields["type"].widget = forms.HiddenInput()
+        
     class Meta:
         model = models.Entity
         exclude = ('imported_by', 'is_single_contact')
@@ -441,7 +444,11 @@ class AddRelationshipForm(forms.Form):
         
         self.contact1 = contact1
         
-        relationship_types = [(r.id, r.name) for r in models.RelationshipType.objects.all()]
+        relationship_types = []
+        for r in models.RelationshipType.objects.all():
+            relationship_types.append((r.id, r.name))
+            if r.reverse:
+                relationship_types.append((-r.id, r.reverse))
         self.fields["relationship_type"].widget = forms.Select(choices=relationship_types) 
         
         widget = ContactAutoComplete(
@@ -450,7 +457,11 @@ class AddRelationshipForm(forms.Form):
         
     def clean_relationship_type(self):
         try:
+            self.reversed_relation = False
             relationship_type = int(self.cleaned_data["relationship_type"])
+            if relationship_type<0:
+                self.reversed_relation = True
+                relationship_type = -relationship_type
             return models.RelationshipType.objects.get(id=relationship_type)
         except ValueError:
             raise ValidationError(_(u"Invalid data"))
@@ -467,10 +478,16 @@ class AddRelationshipForm(forms.Form):
             raise ValidationError(_(u"Contact does not exist"))
         
     def save(self):
-        contact2 = self.cleaned_data["contact2"]
+        if self.reversed_relation:
+            contact1 = self.cleaned_data["contact2"]
+            contact2 = self.contact1
+        else:
+            contact1 = self.contact1
+            contact2 = self.cleaned_data["contact2"]
+        
         rt = self.cleaned_data["relationship_type"]
         return models.Relationship.objects.create(
-                contact1=self.contact1, contact2=contact2, relationship_type=rt)    
+                contact1=contact1, contact2=contact2, relationship_type=rt)    
         
 class ActionDoneForm(forms.ModelForm):
     
