@@ -38,6 +38,35 @@ class EntityNameStartsWithSearchForm(SearchFieldForm):
         return {'entity__name__istartswith': self._value}
 
 
+class HasEntityForm(YesNoSearchFieldForm):
+    _name = 'has_entity'
+    _label = _(u'Has entity?')
+        
+    def get_lookup(self):
+        no_entity = Q(entity__is_single_contact=True)
+        if self.is_yes():
+            return ~no_entity
+        else:
+            return no_entity
+
+class EntityByModifiedDate(TwoDatesForm):
+    _name = 'entity_by_modified_date'
+    _label = _(u'Entity by modified date')
+        
+    def get_lookup(self):
+        dt1, dt2 = self._get_dates()
+        dt2 += timedelta(1)
+        return Q(entity__is_single_contact=False, entity__modified__gte=dt1, entity__modified__lt=dt2)
+
+class ContactByModifiedDate(TwoDatesForm):
+    _name = 'contact_by_modified_date'
+    _label = _(u'Contact by modified date')
+        
+    def get_lookup(self):
+        dt1, dt2 = self._get_dates()
+        dt2 += timedelta(1)
+        return {'modified__gte': dt1, 'modified__lt': dt2, }
+
 class CitySearchForm(SearchFieldForm):
     _name = 'city'
     _label = _(u'City')
@@ -752,3 +781,49 @@ class ContactsAndEntitiesByChangeDate(TwoDatesForm):
         return Q(modified__gte=dt1, modified__lte=dt2) | Q(created__gte=dt1, created__lte=dt2) | \
             Q(entity__modified__gte=dt1, entity__modified__lte=dt2) | \
             Q(entity__created__gte=dt1, entity__created__lte=dt2)
+        
+class ContactsRelationshipByType(SearchFieldForm):
+    _name = 'contacts_by_relationship_type'
+    _label = _(u'Relationship type')
+    
+    def __init__(self, *args, **kwargs):
+        super(ContactsRelationshipByType, self).__init__(*args, **kwargs)
+        relationship_types = []
+        for r in models.RelationshipType.objects.all():
+            relationship_types.append((r.id, r.name))
+            if r.reverse:
+                relationship_types.append((-r.id, r.reverse))
+        field = forms.CharField(label=self._label, widget=forms.Select(choices=relationship_types))
+        self._add_field(field)
+        
+    def get_lookup(self):
+        relationship_ids = []
+        value, is_reverse = int(self._value), False
+        if value<0:
+            value, is_reverse = -value, True
+        t = models.RelationshipType.objects.get(id=value)
+        for r in models.Relationship.objects.filter(relationship_type__id=t.id):
+            if t.reverse:
+                if is_reverse:
+                    relationship_ids.append(r.contact2.id)
+                else:
+                    relationship_ids.append(r.contact1.id)
+            else:
+                relationship_ids += [r.contact1.id, r.contact2.id]
+        relationship_ids = list(set(relationship_ids))  
+        return Q(id__in=(relationship_ids))
+    
+class ContactsRelationshipByDate(TwoDatesForm):
+    _name = 'contacts_by_relationship_dates'
+    _label = _(u'Relationship dates')
+        
+    def get_lookup(self):
+        relationship_ids = []
+        dt1, dt2 = self._get_dates()
+        dt2 = dt2 + timedelta(1)
+        for r in models.Relationship.objects.filter(created__gte=dt1, created__lt=dt2):
+            relationship_ids = [r.contact1.id, r.contact2.id]
+        relationship_ids = list(set(relationship_ids))  
+        return Q(id__in=(relationship_ids))
+
+    
\ No newline at end of file
