@@ -19,6 +19,89 @@ class BaseTestCase(TestCase):
 
     def _login(self):
         self.client.login(username="toto", password="abc")
+        
+class CreateEntityTest(BaseTestCase):
+
+    def test_view_create_entity_no_type(self):
+        url = reverse('crm_create_entity', args=[0])
+        response = self.client.get(url)
+        self.assertEqual(200, response.status_code)
+        self.assertEqual(models.Entity.objects.count(), 0)
+    
+    def test_view_create_entity_with_type(self):
+        t = mommy.make(models.EntityType)
+        url = reverse('crm_create_entity', args=[t.id])
+        response = self.client.get(url)
+        self.assertEqual(200, response.status_code)
+        self.assertEqual(models.Entity.objects.count(), 0)
+        
+    def test_create_entity_no_type(self):
+        url = reverse('crm_create_entity', args=[0])
+        response = self.client.post(url, data={'name': "ABC"})
+        self.assertEqual(302, response.status_code)
+        self.assertEqual(models.Entity.objects.count(), 1)
+        e = models.Entity.objects.all()[0]
+        self.assertEqual(response["Location"],
+            "http://testserver"+reverse("crm_edit_contact_after_entity_created", args=[e.default_contact.id]))
+        self.assertEqual(e.name, "ABC")
+        self.assertEqual(e.type, None)
+    
+    def test_create_entity_with_type(self):
+        t = mommy.make(models.EntityType)
+        url = reverse('crm_create_entity', args=[t.id])
+        response = self.client.post(url, data={'name': "ABC", "type": t.id})
+        self.assertEqual(302, response.status_code)
+        self.assertEqual(models.Entity.objects.count(), 1)
+        e = models.Entity.objects.all()[0]
+        self.assertEqual(response["Location"],
+            "http://testserver"+reverse("crm_edit_contact_after_entity_created", args=[e.default_contact.id]))
+        self.assertEqual(e.name, "ABC")
+        self.assertEqual(e.type, t)
+        
+    def test_create_entity_with_type_after(self):
+        t = mommy.make(models.EntityType)
+        url = reverse('crm_create_entity', args=[0])
+        response = self.client.post(url, data={'name': "ABC", "type": t.id})
+        self.assertEqual(302, response.status_code)
+        self.assertEqual(models.Entity.objects.count(), 1)
+        e = models.Entity.objects.all()[0]
+        self.assertEqual(response["Location"],
+            "http://testserver"+reverse("crm_edit_contact_after_entity_created", args=[e.default_contact.id]))
+        self.assertEqual(e.name, "ABC")
+        self.assertEqual(e.type, t)
+        
+    def test_view_create_entity_unknown_type(self):
+        t = mommy.make(models.EntityType)
+        url = reverse('crm_create_entity', args=[2222])
+        response = self.client.get(url)
+        self.assertEqual(404, response.status_code)
+        self.assertEqual(models.Entity.objects.count(), 0)
+        
+        response = self.client.post(url, data={'name': "ABC", "type": 2222})
+        self.assertEqual(404, response.status_code)
+        self.assertEqual(models.Entity.objects.count(), 0)
+        
+        url = reverse('crm_create_entity', args=[t.id])
+        response = self.client.post(url, data={'name': "ABC", "type": "2222"})
+        self.assertEqual(200, response.status_code)
+        self.assertEqual(models.Entity.objects.count(), 0)
+        
+        
+    def test_view_create_entity_invalid_type(self):
+        t = mommy.make(models.EntityType)
+        url = reverse('crm_create_entity', args=[2222]).replace("2222", "aaa")
+        response = self.client.get(url)
+        self.assertEqual(404, response.status_code)
+        self.assertEqual(models.Entity.objects.count(), 0)
+        
+        response = self.client.post(url, data={'name': "ABC", "type": 2222})
+        self.assertEqual(404, response.status_code)
+        self.assertEqual(models.Entity.objects.count(), 0)
+        
+        url = reverse('crm_create_entity', args=[t.id])
+        response = self.client.post(url, data={'name': "ABC", "type": "aaaaa"})
+        self.assertEqual(200, response.status_code)
+        self.assertEqual(models.Entity.objects.count(), 0)
 
 class OpportunityTest(BaseTestCase):
 
@@ -1561,6 +1644,31 @@ class RelationshipTest(BaseTestCase):
         r = models.Relationship.objects.get(contact1=contact1, contact2=contact2)
         self.assertEqual(r.relationship_type, relation_type)
         
+    def test_add_reversed_relationship(self):
+        contact1 = mommy.make(models.Contact, firstname="Alex", lastname="Ferguson")
+        contact2 = mommy.make(models.Contact, firstname="Eric", lastname="Cantona")
+        
+        relation_type = mommy.make(models.RelationshipType, name="Coach of", reverse="Player of")
+        
+        url = reverse("crm_add_relationship", args=[contact2.id])
+        response = self.client.get(url)
+        self.assertEqual(200, response.status_code)
+        self.assertContains(response, relation_type.name)
+        self.assertContains(response, relation_type.reverse)
+        
+        response = self.client.post(url, data={'contact2': contact1.id, 'relationship_type': -relation_type.id})
+        self.assertEqual(200, response.status_code)
+        
+        errors = BS4(response.content).select('.errorlist')
+        self.assertEqual(list(errors), [])
+        
+        #refresh
+        contact1 = models.Contact.objects.get(id=contact1.id)
+        contact2 = models.Contact.objects.get(id=contact2.id)
+        
+        r = models.Relationship.objects.get(contact1=contact1, contact2=contact2)
+        self.assertEqual(r.relationship_type, relation_type)
+        
     def test_add_relationship_no_contact(self):
         contact1 = mommy.make(models.Contact, firstname="John", lastname="Lennon")
         contact2 = mommy.make(models.Contact, firstname="Paul", lastname="McCartney")
