@@ -3,7 +3,7 @@
 from django.test import TestCase
 from django.contrib.auth.models import User, Permission
 from django.core.urlresolvers import reverse
-from datetime import datetime
+from datetime import datetime, date, timedelta
 from model_mommy import mommy
 from sanza.Crm import models
 from sanza.Emailing.models import Emailing, MagicLink
@@ -13,7 +13,6 @@ from django.core import mail
 from django.conf import settings
 from BeautifulSoup import BeautifulSoup
 from bs4 import BeautifulSoup as BeautifulSoup4
-from datetime import date
 from django.utils.translation import ugettext as _
 
 def get_form_errors(response):
@@ -1132,4 +1131,235 @@ class HasZipTest(BaseTestCase):
         self.assertNotContains(response, contact1.lastname)
         self.assertContains(response, contact2.lastname)
         self.assertNotContains(response, contact3.lastname)
-        self.assertNotContains(response, contact4.lastname)
\ No newline at end of file
+        self.assertNotContains(response, contact4.lastname)
+
+class HasEntitySearchTest(BaseTestCase):
+    
+    def test_contact_has_entity(self):
+        
+        entity1 = mommy.make(models.Entity, is_single_contact=False)
+        entity2 = mommy.make(models.Entity, is_single_contact=True)
+        
+        contact1 = entity1.default_contact
+        contact1.lastname = "AZERTYUIOP"
+        contact1.save()
+        
+        contact2 = entity2.default_contact
+        contact2.lastname = "QWERTYUIOP"
+        contact2.save()
+        
+        
+        url = reverse('search')
+        
+        data = {"gr0-_-has_entity-_-0": 1}
+        
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        
+        self.assertContains(response, contact1.lastname)
+        self.assertNotContains(response, contact2.lastname)
+        
+    def test_contact_doesnt_have_entity(self):
+        
+        entity1 = mommy.make(models.Entity, is_single_contact=False)
+        entity2 = mommy.make(models.Entity, is_single_contact=True)
+        
+        contact1 = entity1.default_contact
+        contact1.lastname = "AZERTYUIOP"
+        contact1.save()
+        
+        contact2 = entity2.default_contact
+        contact2.lastname = "QWERTYUIOP"
+        contact2.save()
+        
+        
+        url = reverse('search')
+        
+        data = {"gr0-_-has_entity-_-0": 0}
+        
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        
+        self.assertNotContains(response, contact1.lastname)
+        self.assertContains(response, contact2.lastname)
+
+        
+class ModifiedSearchTest(BaseTestCase):
+    
+    def test_contact_modified_today(self):
+        
+        contact1 = mommy.make(models.Contact, lastname="Azertuiop")
+        
+        url = reverse('search')
+        
+        data = {"gr0-_-contact_by_modified_date-_-0": '{0} {0}'.format(date.today().strftime("%d/%m/%Y"))}
+        
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        
+        self.assertContains(response, contact1.lastname)
+        
+    def test_contact_modified_tomorrow(self):
+        
+        contact1 = mommy.make(models.Contact, lastname="Azertuiop")
+        
+        url = reverse('search')
+        
+        dt = date.today() + timedelta(1)
+        data = {"gr0-_-contact_by_modified_date-_-0": '{0} {0}'.format(dt.strftime("%d/%m/%Y"))}
+        
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        
+        self.assertNotContains(response, contact1.lastname)
+        
+    def test_entity_modified_today(self):
+        
+        contact1 = mommy.make(models.Contact, lastname="Azertuiop")
+        
+        url = reverse('search')
+        
+        data = {"gr0-_-entity_by_modified_date-_-0": '{0} {0}'.format(date.today().strftime("%d/%m/%Y"))}
+        
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        
+        self.assertContains(response, contact1.lastname)
+        
+    def test_entity_modified_today_no_single_contact(self):
+        
+        contact1 = mommy.make(models.Contact, lastname="Azertuiop")
+        entity2 = mommy.make(models.Entity, is_single_contact=True)
+        contact2 = entity2.default_contact
+        contact2.lastname = "QWERTYUIOP"
+        contact2.save()
+        
+        url = reverse('search')
+        
+        data = {"gr0-_-entity_by_modified_date-_-0": '{0} {0}'.format(date.today().strftime("%d/%m/%Y"))}
+        
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        
+        self.assertContains(response, contact1.lastname)
+        self.assertNotContains(response, contact2.lastname)
+        
+    def test_entity_modified_tomorrow(self):
+        
+        contact1 = mommy.make(models.Contact, lastname="Azertuiop")
+        
+        url = reverse('search')
+        
+        dt = date.today() + timedelta(1)
+        data = {"gr0-_-entity_by_modified_date-_-0": '{0} {0}'.format(dt.strftime("%d/%m/%Y"))}
+        
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        
+        self.assertNotContains(response, contact1.lastname)
+        
+class RelationshipSearchTest(BaseTestCase):
+    
+    def test_contact_by_relationship_type_with_reverse(self):    
+        anakin = mommy.make(models.Contact, firstname="Anakin", lastname="Skywalker")
+        obi = mommy.make(models.Contact, firstname="Obi-Wan", lastname="Kenobi")
+        doe = mommy.make(models.Contact, firstname="Doe", lastname="John")
+        
+        master = mommy.make(models.RelationshipType, name="Master", reverse="Padawan")
+        
+        r = models.Relationship.objects.create(contact1=obi, contact2=anakin, relationship_type=master)
+        
+        url = reverse('search')
+        
+        data = {"gr0-_-contacts_by_relationship_type-_-0": master.id}
+        
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        
+        self.assertContains(response, obi.lastname)
+        self.assertNotContains(response, anakin.lastname)
+        self.assertNotContains(response, doe.lastname)
+        
+    def test_contact_by_relationship_type_reverse(self):    
+        anakin = mommy.make(models.Contact, firstname="Anakin", lastname="Skywalker")
+        obi = mommy.make(models.Contact, firstname="Obi-Wan", lastname="Kenobi")
+        doe = mommy.make(models.Contact, firstname="Doe", lastname="John")
+        
+        master = mommy.make(models.RelationshipType, name="Master", reverse="Padawan")
+        
+        r = models.Relationship.objects.create(contact1=obi, contact2=anakin, relationship_type=master)
+        
+        url = reverse('search')
+        
+        data = {"gr0-_-contacts_by_relationship_type-_-0": -master.id}
+        
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        
+        self.assertNotContains(response, obi.lastname)
+        self.assertContains(response, anakin.lastname)
+        self.assertNotContains(response, doe.lastname)
+        
+    def test_contact_by_relationship_type(self):    
+        john = mommy.make(models.Contact, firstname="Hohn", lastname="Lennon")
+        ringo = mommy.make(models.Contact, firstname="Ringo", lastname="Star")
+        doe = mommy.make(models.Contact, firstname="Doe", lastname="John")
+        
+        friends = mommy.make(models.RelationshipType, name="Fiends")
+        
+        r = models.Relationship.objects.create(contact1=john, contact2=ringo, relationship_type=friends)
+        
+        url = reverse('search')
+        
+        data = {"gr0-_-contacts_by_relationship_type-_-0": friends.id}
+        
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        
+        self.assertContains(response, john.lastname)
+        self.assertContains(response, ringo.lastname)
+        self.assertNotContains(response, doe.lastname)
+        
+    def test_contact_by_relationship_date(self):    
+        john = mommy.make(models.Contact, firstname="Hohn", lastname="Lennon")
+        ringo = mommy.make(models.Contact, firstname="Ringo", lastname="Star")
+        doe = mommy.make(models.Contact, firstname="Doe", lastname="John")
+        
+        friends = mommy.make(models.RelationshipType, name="Fiends")
+        
+        r = models.Relationship.objects.create(contact1=john, contact2=ringo, relationship_type=friends)
+        
+        url = reverse('search')
+        
+        dt = date.today()
+        data = {"gr0-_-contacts_by_relationship_dates-_-0": '{0} {0}'.format(dt.strftime("%d/%m/%Y"))}
+        
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        
+        self.assertContains(response, john.lastname)
+        self.assertContains(response, ringo.lastname)
+        self.assertNotContains(response, doe.lastname)
+        
+    def test_contact_by_relationship_not_in_date(self):    
+        john = mommy.make(models.Contact, firstname="Hohn", lastname="Lennon")
+        ringo = mommy.make(models.Contact, firstname="Ringo", lastname="Star")
+        doe = mommy.make(models.Contact, firstname="Doe", lastname="John")
+        
+        friends = mommy.make(models.RelationshipType, name="Fiends")
+        
+        r = models.Relationship.objects.create(contact1=john, contact2=ringo, relationship_type=friends)
+        
+        url = reverse('search')
+        
+        dt = date.today() + timedelta(1)
+        data = {"gr0-_-contacts_by_relationship_dates-_-0": '{0} {0}'.format(dt.strftime("%d/%m/%Y"))}
+        
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        
+        self.assertNotContains(response, john.lastname)
+        self.assertNotContains(response, ringo.lastname)
+        self.assertNotContains(response, doe.lastname)
+        
+        
\ No newline at end of file
