@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+from datetime import datetime
 import logging
 logger = logging.getLogger("sanza_crm")
 
@@ -11,3 +12,7 @@ def log_error(view_func):
             logger.exception("exception")
             raise
     return wrapper
+
+def now_rounded():
+    now = datetime.now()
+    return datetime(now.year, now.month, now.day, now.hour, now.minute, 0, 0)
